==> members-facade-1.0.1-20181217.114619-65-sources.jar: com/bizvane/members/facade/models/QueryCustomizeLabelListRequestVO.java <==
package com.bizvane.members.facade.models;

import java.io.Serializable;

import io.swagger.annotations.ApiModelProperty;

public class QueryCustomizeLabelListRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;
  
  private Long brandId;
  
  private String labelType;
  
  @ApiModelProperty(value = "标签名称", name = "labelName", required = false)
  private String labelName;

  @ApiModelProperty(value = "使用次数起始", name = "count", required = false)
  private Integer countStart;
  
  @ApiModelProperty(value = "使用次数结束", name = "count", required = false)
  private Integer countEnd;
  
  @ApiModelProperty(value = "创建人", name = "createUserName", required = false)
  private String createUserName;

  public Long getBrandId() {
    return brandId;
  }

  public void setBrandId(Long brandId) {
    this.brandId = brandId;
  }

  public String getLabelName() {
    return labelName;
  }

  public void setLabelName(String labelName) {
    this.labelName = labelName;
  }

  public Integer getCountStart() {
    return countStart;
  }

  public void setCountStart(Integer countStart) {
    this.countStart = countStart;
  }

  public Integer getCountEnd() {
    return countEnd;
  }

  public void setCountEnd(Integer countEnd) {
    this.countEnd = countEnd;
  }

  public String getCreateUserName() {
    return createUserName;
  }

  public void setCreateUserName(String createUserName) {
    this.createUserName = createUserName;
  }

  public String getLabelType() {
    return labelType;
  }

  public void setLabelType(String labelType) {
    this.labelType = labelType;
  }

  
  
}

==> members-facade-2.0.0-20191029.130417-130-sources.jar: com/bizvane/members/facade/models/QueryCustomizeLabelListRequestVO.java <==
package com.bizvane.members.facade.models;

import java.io.Serializable;

import io.swagger.annotations.ApiModelProperty;

public class QueryCustomizeLabelListRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;
  
  private Long companyId;

  private Long brandId;
  
  private String labelType;
  
  @ApiModelProperty(value = "标签名称", name = "labelName", required = false)
  private String labelName;

  @ApiModelProperty(value = "使用次数起始", name = "count", required = false)
  private Integer countStart;
  
  @ApiModelProperty(value = "使用次数结束", name = "count", required = false)
  private Integer countEnd;
  
  @ApiModelProperty(value = "创建人", name = "createUserName", required = false)
  private String createUserName;

  public Long getBrandId() {
    return brandId;
  }

  public void setBrandId(Long brandId) {
    this.brandId = brandId;
  }

  public String getLabelName() {
    return labelName;
  }

  public void setLabelName(String labelName) {
    this.labelName = labelName;
  }

  public Integer getCountStart() {
    return countStart;
  }

  public void setCountStart(Integer countStart) {
    this.countStart = countStart;
  }

  public Integer getCountEnd() {
    return countEnd;
  }

  public void setCountEnd(Integer countEnd) {
    this.countEnd = countEnd;
  }

  public String getCreateUserName() {
    return createUserName;
  }

  public void setCreateUserName(String createUserName) {
    this.createUserName = createUserName;
  }

  public String getLabelType() {
    return labelType;
  }

  public void setLabelType(String labelType) {
    this.labelType = labelType;
  }

  public Long getCompanyId() {
    return companyId;
  }

  public void setCompanyId(Long companyId) {
    this.companyId = companyId;
  }
}
